pub struct SseState<T> {
pub sessions: Arc<DashMap<Uuid, SseSession<T>>>,
}Expand description
SSE state
Fields
sessions: Arc<DashMap<Uuid, SseSession<T>>>Implementations
Sourceimpl<T> SseState<T>
impl<T> SseState<T>
pub fn add_session( &self, id: Uuid, data: Option<T>, sender: Sender<Event>, ) -> Option<SseSession<T>>
pub fn remove_session(&self, id: Uuid) -> Option<(Uuid, SseSession<T>)>
Sourcepub async fn send_message(&self, id: Uuid, data: Data) -> Option<()>
pub async fn send_message(&self, id: Uuid, data: Data) -> Option<()>
Sends a message to session id
Sourcepub async fn broadcast(&self, data: Data) -> usize
pub async fn broadcast(&self, data: Data) -> usize
Broadcast a message to all sessions and returns the number of sent messages
Sourcepub async fn broadcast_all_but(&self, id: Uuid, data: Data) -> usize
pub async fn broadcast_all_but(&self, id: Uuid, data: Data) -> usize
Broadcast a message to all sessions but one id and returns the number of sent messages